@@ -1,11 +1,15 @@
 use handlebars::Handlebars;
 
-pub mod strings;
-pub mod math;
 pub mod date;
+pub mod gist;
+pub mod math;
+pub mod strings;
+pub mod tweet;
 
 pub fn addhelpers(x: &mut Handlebars) {
     strings::addhelpers(x);
     math::addhelpers(x);
-    date::addhelpers(x)
-}
\ No newline at end of file
+    date::addhelpers(x);
+    tweet::addhelpers(x);
+    gist::addhelpers(x);
+}
